BarcodeFormat enum

The supported barcode formats for PDF scanning.

Inheritance
Available extensions

Values

qr → const BarcodeFormat

QR Code 2D barcode format.

pdf417 → const BarcodeFormat

PDF417 2D stacked barcode format.

aztec → const BarcodeFormat

Aztec 2D barcode format.

dataMatrix → const BarcodeFormat

DataMatrix 2D barcode format.

code128 → const BarcodeFormat

Code 128 1D linear barcode format.

ean13 → const BarcodeFormat

EAN-13 1D linear barcode format.

ean8 → const BarcodeFormat

EAN-8 1D linear barcode format.

upc → const BarcodeFormat

UPC (UPC-A and UPC-E) 1D linear barcode format.

itf → const BarcodeFormat

Interleaved 2 of 5 (ITF) 1D linear barcode format.

codabar → const BarcodeFormat

Codabar 1D linear barcode format.

all → const BarcodeFormat

All supported 1D and 2D barcode formats.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeString() String

Available on BarcodeFormat, provided by the BarcodeFormatExtension extension

Converts the enum to a string that the native platforms expect.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BarcodeFormat>
A constant List of the values in this enum, in order of their declaration.