DecoderConfig class
Configuration options for PDF barcode scanning.
Constructors
-
DecoderConfig({int dpi = 300, bool firstPageOnly = false, bool stopAfterFirst = false, int? maxPages, List<
BarcodeFormat> formats = const [BarcodeFormat.all]}) -
Constructs a DecoderConfig.
const
Properties
- dpi → int
-
The resolution (dots per inch) at which each PDF page is rendered before scanning.
final
- firstPageOnly → bool
-
Whether to only scan the first page of the PDF document.
final
-
formats
→ List<
BarcodeFormat> -
The list of BarcodeFormat formats to detect.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxPages → int?
-
The maximum number of pages to scan from the beginning of the PDF.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopAfterFirst → bool
-
Whether to terminate scanning immediately once the first barcode is detected.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Serializes the configuration into a map for method channel communication.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited