PdfBarcodeDecoderPlatform class abstract
The interface that platform-specific implementations of pdf_barcode_decoder must extend.
- Inheritance
-
- Object
- PlatformInterface
- PdfBarcodeDecoderPlatform
- Implementers
Constructors
- PdfBarcodeDecoderPlatform()
- Constructs a PdfBarcodeDecoderPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decodePdf(
{String? filePath, Uint8List? pdfBytes, required DecoderConfig config}) → Future< List< PdfBarcode> > -
Platform interface method to decode barcodes from either
filePathorpdfBytes. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ PdfBarcodeDecoderPlatform
-
The default instance of PdfBarcodeDecoderPlatform to use.
getter/setter pair